v0.3.0 (June 28, 2021)
======================
  * Add research examples to documentation (#77)
  * ENH: Add dataset fetchers (#76)
  * Adds error handling for cases where users forget to set target_cols. (#73)
  * ENH: Add unsupervised boolean parameter to load_afq_data (#71)
  * ENH: Add bundle profile plotting function (#69)
  * Remove transformers that were migrated to groupyr (#68)
  * DEP: Loosen groupyr dependency (#67)
  * DEP: Loosen dependency requirements (#66)
  * Fixes broken links (#65)
  * ENH: Stratify bootstrap replicants in SerialBaggingClassifier (#61)
  * ENH: Add SerialBagging classes (#60)

